leaftools.label_leaves_in_expr_with_melodic_counterpoint_intervals
==================================================================

.. autofunction:: abjad.tools.leaftools.label_leaves_in_expr_with_melodic_counterpoint_intervals.label_leaves_in_expr_with_melodic_counterpoint_intervals
